'''
    Function imports.
'''

from .choose  import choose
from .confirm import confirm
from .file    import file
from .search  import search
from .input   import input
from .pager   import pager
from .write   import write
from .spin    import spin

# EOF